{% extends "admin/base.html" %}

{% block title %}
    {% if subtitle %}
        {{ subtitle }} |
    {% endif %}
    {{ title }} | {{ site_title|default:_("Django site admin") }}
{% endblock %}

{% block branding %}
    <div id="site-name">
        <a href="{% url 'admin:index' %}">
            <img src="{{ STATIC_URL }}cap/img/logo.png" alt="Logo">
        </a>
    </div>
    {% if user.is_anonymous %}
        {% include "admin/color_theme_toggle.html" %}
    {% endif %}
{% endblock %}

{% block nav-global %}
{% endblock %}
