{% load i18n %}
<details data-filter-title="{{ title }}" open>
    <summary>
        {{ title|capfirst }}
    </summary>
    <ul>
        {% for choice in choices %}
            <li {% if choice.selected %} class="selected"{% endif %}>
                <a href="{{ choice.query_string|iriencode }}">{{ choice.display }}</a>
            </li>
        {% endfor %}
    </ul>
</details>
